/*

qunatity_usup.do

Created by : Isabelle, August 2019

This Dofile : 
			- Merge trade data with information on CN8 categories which quantities are not defined in kgs but in a physical unit
			- if collapse==1, collapse data by id_conc and replace quantities defined in different units by missing values

Input:
			- $inputpath\correspondance_nc8_usup.csv correspondance between CN8 products and usup
			- Trade data in $dataset

Output: 
			- $outputdata Input dataset augmented with usup information
			- if collapse==1, $outputdata is collapsed by $dimensioncollapse and two variables are added: quantity and unitv, both defined either in kgs or in physical units

Notes: 
From 2006 on, kgs is no longer mandatory whenever usup is provided (indice_masse_nulle==0)
Better to use physical units, whenever possible

*/

* 0. Define working paths and names of input and output datasets
global datapath // Working path
global dopath // Where do files are saved
global inputpath // Where data with the list of usup are saved
global dataset  // Name of the input dataset (data at the CN8 level)
global outputdata // Name of the output dataset
global collapse 1
global dimensioncollapse "siren iso2 year month id_conc" // Dimension for the collapse

cd $datapath


* 1. Input usup table (usup per nc8*year) which associates a product with an usup (default = 00 = no usup)
clear
insheet using $inputpath\correspondance_nc8_usup.csv, delimiter(";") names
rename ann_nomenc year
tostring cod_nc8, g(nc8)
replace nc8="0"+nc8 if length(nc8)==7
drop if length(nc8)==3
keep year nc8 cod_usup
duplicates drop year nc8 cod_usup, force
duplicates tag year nc8, g(_)
keep if _==0|cod_usup!=.
drop _
sort  nc8 year
save temp2, replace

* 2. Merge with trade data
use $dataset, clear
sort nc8 year
merge m:1 nc8 year using temp2
drop if _m==2
drop _merge
tostring cod_usup, replace
replace cod_usup="00" if cod_usup=="."
replace cod_usup="0"+cod_usup if length(cod_usup)==1

* 3. if collapse=1, collapse by id_conc
* Export can always be added. 
* Masse can be added although comparability of kilos might be questionable
* Usup can be added if it is the same units

g collapse = $collapse

if collapse==1{
	bys id_conc: egen count_usup=nvals(cod_usup)
	bys id_conc year: egen count_usup_pery=nvals(cod_usup)
	
	destring cod_usup, g(cod_usup_n)

	collapse (sum) export kgs unites (max) count_nc_pery count_usup_pery cod_usup_n, by($dimensioncollapse )
	replace usup=. if count_usup_pery!=1 // cannot sum various physical units
	replace cod_usup_n=. if count_usup_pery!=1
	tostring cod_usup_n, g(cod_usup)
	replace cod_usup="00" if cod_usup=="."
	replace cod_usup="0"+cod_usup if length(cod_usup)==1
	count if cod_usup=="00"
	count if cod_usup=="00" & masse==0
	count if cod_usup=="00" & masse==0 & usup==0
* when cod_usup="00" the quantity is in kilos
* do we want to compare kilos across nc8 within an id_conc?
	g quantity=kgs  if cod_usup=="00" // Define quantities in kgs if cod_usup=="00"
	g unitv=export/kgs if cod_usup=="00"
	count if cod_usup!="00"
	count if cod_usup!="00" & usup==0
	count if cod_usup!="00" & masse==0 & usup==0
* When cod_usup!="00" the quantity is usually in usup. It sometimes happens however that usup==0 & masse!=0
	replace quantity=unites if cod_usup!="00"  // Define quantities in physical units if cod_usup!="00"
	replace unitv=export/unites if cod_usup!="00"

	* check that usup is comparable over time within an id_conc
	bys id_conc: egen _=nvals(cod_usup)
	sum _ if count_usup_pery==1, d
	* Warning: it can happen that usup is changing over time in which case usup is not longer comparable over time within an id_conc
	
	drop count_nc_pery count_usup_pery 
}
drop collapse 
save $outputdata, replace


